@@ -9,15 +9,14 @@ namespace uu {
 namespace net {
 
 /**
- * Louvain algorithm for undirected unweighted networks.
- *
- * (Note: to extend this to weighted networks, if needed in the future, it is sufficient to
- * update the convert() function used inside the method.)
+ * Louvain algorithm for undirected networks.
+ * If the network is weighted, weights are automatically considered.
  */
 template <typename G>
 std::unique_ptr<CommunityStructure<Network>>
         louvain(
-            const G* g
+            const G* g,
+            double gamma = 1.0
         );
 
 }
