@@ -2,13 +2,14 @@
 #define UU_CORE_ARULES_GENERATESUBSETS_H_
 
 #include <vector>
+#include <cstddef>
 
 namespace uu {
 namespace core {
 
-std::vector<std::vector<size_t>>
+std::vector<std::vector<std::size_t>>
 generate_subsets(
-                 const std::vector<size_t>& items
+                 const std::vector<std::size_t>& items
                  );
 
 }
