@@ -11,9 +11,9 @@ namespace core {
 void
 read_transactions(
       const std::string& file_name,
-      std::unordered_map<size_t,std::string>& trans,
-      std::unordered_map<size_t,std::string>& items,
-      std::vector<std::vector<size_t>>& data,
+      std::unordered_map<std::size_t,std::string>& trans,
+      std::unordered_map<std::size_t,std::string>& items,
+      std::vector<std::vector<std::size_t>>& data,
       bool has_tid = false
       );
 
