@@ -17,5 +17,5 @@ ExternalLibException::what() const throw()
     return value.data();
 }
 
-} // namespace core
-} // namespace uu
+}
+}
