@@ -16,7 +16,7 @@ std::unique_ptr<C>
 vslice(
     const std::string& cube_name,
     C* cube,
-    const std::vector<std::vector<size_t>>& indexes
+    const std::vector<std::vector<std::size_t>>& indexes
 );
 
 template <typename C, class D>
@@ -73,21 +73,21 @@ class
     /**
      * Returns the number of elements in the cube.
      */
-    size_t
+    std::size_t
     size(
     ) const;
 
     /**
      * Returns the order (number of dimensions) of this cube.
      */
-    size_t
+    std::size_t
     order(
     ) const;
 
     /**
      * Returns the number of members for each dimension.
      */
-    std::vector<size_t>
+    std::vector<std::size_t>
     dsize(
     ) const;
 
@@ -118,7 +118,7 @@ class
      */
     const std::vector<std::string>&
     members(
-        size_t dim_idx
+        std::size_t dim_idx
     ) const;
 
     /** Returns an iterator to the first vertex in the cube */
@@ -181,7 +181,7 @@ class
      */
     const Vertex*
     at(
-        size_t pos
+        std::size_t pos
     ) const;
 
     /** Returns a random vertex, with uniform probability. */
@@ -267,12 +267,12 @@ class
     void
     sort(
         const std::string& dim_name,
-        const std::vector<size_t>& f
+        const std::vector<std::size_t>& f
     );
     
     void
     pivot(
-        const std::vector<size_t>& f
+        const std::vector<std::size_t>& f
     );
     
     /**
@@ -281,7 +281,7 @@ class
      */
     VertexStore*
     cell(
-        const std::vector<size_t>& index
+        const std::vector<std::size_t>& index
     );
 
     /**
@@ -290,7 +290,7 @@ class
      */
     const VertexStore*
     cell(
-        const std::vector<size_t>& index
+        const std::vector<std::size_t>& index
     ) const;
 
     /**
@@ -312,7 +312,7 @@ class
     ) const;
 
     /** Returns the number of cells in the cube. */
-    size_t
+    std::size_t
     num_cells(
     ) const;
 
@@ -347,7 +347,7 @@ class
     (
         const std::string& cube_name,
         VCube* cube,
-        const std::vector<std::vector<size_t>>& indexes
+        const std::vector<std::vector<std::size_t>>& indexes
     );
 
 
@@ -401,7 +401,7 @@ class
      */
     VertexStore*
     init(
-        const std::vector<size_t>& index,
+        const std::vector<std::size_t>& index,
         const std::shared_ptr<VertexStore>& store
     );
 
@@ -410,7 +410,7 @@ class
      */
     VertexStore*
     init(
-        size_t pos,
+        std::size_t pos,
         const std::shared_ptr<VertexStore>& store
     );
 
@@ -419,7 +419,7 @@ class
      */
     VertexStore*
     init(
-        const std::vector<size_t>& index
+        const std::vector<std::size_t>& index
     );
 
     /**
@@ -427,7 +427,7 @@ class
      */
     VertexStore*
     init(
-        size_t pos
+        std::size_t pos
     );
 
     /**
@@ -445,7 +445,7 @@ class
      */
     void
     register_obs(
-        const std::vector<size_t>& index
+        const std::vector<std::size_t>& index
     );
 
     /**
@@ -454,7 +454,7 @@ class
      */
     void
     register_obs(
-        size_t pos
+        std::size_t pos
     );
 
   private:
